==> qgis-1.7.4.tar.bz2: qgis-1.7.4/src/core/gps/qgsgpsconnectionregistry.cpp <==
/***************************************************************************
                          qgsgpsconnectionregistry.cpp  -  description
                          ----------------------------
    begin                : December 27th, 2009
    copyright            : (C) 2009 by Marco Hugentobler
    email                : marco at hugis dot net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qgsgpsconnectionregistry.h"
#include "qgsgpsconnection.h"

QgsGPSConnectionRegistry* QgsGPSConnectionRegistry::mInstance = 0;

QgsGPSConnectionRegistry::QgsGPSConnectionRegistry()
{

}

QgsGPSConnectionRegistry::~QgsGPSConnectionRegistry()
{
  QSet<QgsGPSConnection*>::iterator it = mConnections.begin();
  for ( ; it != mConnections.end(); ++it )
  {
    delete *it;
  }
}

QgsGPSConnectionRegistry* QgsGPSConnectionRegistry::instance()
{
  if ( !mInstance )
  {
    mInstance = new QgsGPSConnectionRegistry();
  }
  return mInstance;
}

void QgsGPSConnectionRegistry::registerConnection( QgsGPSConnection* c )
{
  mConnections.insert( c );
}

void QgsGPSConnectionRegistry::unregisterConnection( QgsGPSConnection* c )
{
  mConnections.remove( c );
}

QList< const QgsGPSConnection* > QgsGPSConnectionRegistry::connectionList() const
{
  QList< const QgsGPSConnection* > list;

  QSet<QgsGPSConnection*>::const_iterator it = mConnections.constBegin();
  for ( ; it != mConnections.constEnd(); ++it )
  {
    list.append( *it );
  }

  return list;
}

==> qgis_2.4.0.orig.tar.bz2: qgis-2.4.0/src/core/gps/qgsgpsconnectionregistry.cpp <==
/***************************************************************************
                          qgsgpsconnectionregistry.cpp  -  description
                          ----------------------------
    begin                : December 27th, 2009
    copyright            : (C) 2009 by Marco Hugentobler
    email                : marco at hugis dot net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qgsgpsconnectionregistry.h"
#include "qgsgpsconnection.h"

QgsGPSConnectionRegistry::QgsGPSConnectionRegistry()
{
}

QgsGPSConnectionRegistry::~QgsGPSConnectionRegistry()
{
  QSet<QgsGPSConnection*>::iterator it = mConnections.begin();
  for ( ; it != mConnections.end(); ++it )
  {
    delete *it;
  }
}

QgsGPSConnectionRegistry* QgsGPSConnectionRegistry::instance()
{
  static QgsGPSConnectionRegistry mInstance;
  return &mInstance;
}

void QgsGPSConnectionRegistry::registerConnection( QgsGPSConnection* c )
{
  mConnections.insert( c );
}

void QgsGPSConnectionRegistry::unregisterConnection( QgsGPSConnection* c )
{
  mConnections.remove( c );
}

QList< QgsGPSConnection* > QgsGPSConnectionRegistry::connectionList() const
{
  return mConnections.toList();
}
